==> zither-1.1.14.tar.gz: zither_prj/apollon/userblock_cut_edit.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

// function WinCls(){
//        window.close()
//                       }
//  window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";
require("./socket.inc");
require("./list_file_upload.inc");

$GEN = $_GET["GEN"];

// $BNAME = $_GET["BNAME"];
$CNAME = $_GET["CNAME"];
$MAILTO = $_GET["MAILTO"];
$MAILCC = $_GET["MAILCC"];
$MAILSEND = $_GET["MAILSEND"];
$PLUSTIME = $_GET["PLUSTIME"];
$STAT = $_GET["STAT"];
$STARTTIME = $_GET["STARTTIME"];
$STOPSETTIME = $_GET["STOPSETTIME"];
$FREE1 = $_GET["FREE1"];
$select = $_GET["SELECT"];



// ֤˴֤륨顼å
if(0 != strcmp("ASCII", mb_detect_encoding($STARTTIME))){
   print("NG NOT ASCII enc \n");
   $STARTTIME = "";
   }
if(0 != strcmp("ASCII", mb_detect_encoding($STOPSETTIME))){
   print("NG NOT ASCII enc \n");
   $STOPSETTIME = "";
   }
if(5 != strlen($STARTTIME)){
   print("NG NOT time format 00:00 \n");
   $STARTTIME = "";
   }
if( 5 != strlen($STOPSETTIME)){
   print("NG NOT time format 00:00 \n");
   $STOPSETTIME = "";
   }
if(!preg_match("/^[0-9]+$/", substr($STARTTIME, 0, 2))){
   print("NG NOT a int\n");
   $STARTTIME = "";
   }
if(!preg_match("/^[0-9]+$/", substr($STOPSETTIME, 3, 4))){
   print("NG NOT a int\n");
   $STOPSETTIME = "";
   }





$new_cname_ok = 0;
$count = 0;
$SE="LIKE";
$EE="=";

// ----- DB ³ ----//

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


// ------ ƤΤǤ -----//
if(0 != strlen($select)){
   $select_get = urldecode($select);
   print("ƤΤǤ $select_get \n");
   $select_data = "update userblock set ";
   }
else{
   echo "NG NOT WHER DATA! \n";
   exit;
   }





// ------ ѹƤκ -----//
print("------ Ƥޤ -----\n");
if(0 != strlen($MAILTO)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " mailto='$MAILTO'";
   }

if(0 != strlen($MAILCC)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " MAILCC='$MAILCC'";
   }

if(0 != strlen($MAILSEND)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " MAILSEND='$MAILSEND'";
   }

if(0 != strlen($PLUSTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " plustime='$PLUSTIME'";
   }

if(0 != strlen($STAT)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " stat='$STAT'";
   }

if(0 != strlen($STARTTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " starttime='$STARTTIME'";
   }

if(0 != strlen($STOPSETTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " stopsettime='$STOPSETTIME'";
   }

if(0 != strlen($FREE1)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " free1='$FREE1'";
   }
print("ؤ󤳤Ƥκ: $select_data ");





// CNAME ѹϥå
if(0 != strlen($CNAME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " cname='$CNAME'";
   $new_cname_ok = 1;

   print("CNAME ѹޤ new_cname_ok = $new_cname_ok\n");
   print("狼 ƻ֥å̾ꥹȺ \n");

   $bname_count = 0;
   $result = pg_query($conn, "select distinct(bname) from userblock $select_get;");
   if(!$result){
      print("banem select , bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num > 0){
      while($bname_count < $num){
         $bname_data[$bname_count] = rtrim(pg_fetch_Result($result, $bname_count, bname));
         print("ֹ ($bname_count) 狼鸡BNAME= $bname_data[$bname_count] ꥹȤɲ\n");
         $bname_count++;
         }
      }
   else{
      print("NG ƻ֥å̵Ǥ \n");
      }
   pg_free_result($result);

   }



print("COUNT = $count DATA $select_data\n");
if(0 == $count){
   print("NG SELECT DATA ERR ѹ̵Τǽλޤ\n");
   exit;
   }



$select_data = $select_data . " $select_get";

print("UPDATE COMMAND = $select_data\n");






print("ѹCNAMEꥹ \n");

$result = pg_query($conn, "select distinct(cname) from userblock $select_get");
if(!$result){
   print("NG bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   exit;
   }
else{
   $cname_count =0;
   while($cname_count < $num){
      $cname_data[$cname_count]  = rtrim(pg_fetch_Result($result, $cname_count, cname));
      print("ֹ ($cname_count) 狼ѹ饤Ȥꥹ CNAME= $cname_data[$cname_count]");
      print("\n");
      $cname_count++;
      }
   }
if($cname_count < 0){
   print("NG:  ѹ饤ȤΥꥹȤޤǤ \n");
   exit;
   }



print("------ userblock DBѹޤ------- \n");


if(0 == strlen($select_data)){
   print("NG NOT select_data");
   exit;
   }
else{
   $result = pg_query($conn, "$select_data");
   print("ƻѹ夦Ǥ select_data = $select_data\n");
   if(!$result){
      print("NG bud query $select_data\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num < 0){
      print("NG ƻ֥å꤬ѹƤޤ\n");
      exit;
      }
   }
if($new_cname_ok == 1){

   print("------ monitor DBѹޤ------- \n");

   for($count = 0; $count < $bname_count; $count++){

      $qudata =  "update monitor set cname = " . "'" . $CNAME . "'" . " where free4 = " . "'" . $bname_data[$count] . "'";

      print("CNAMEѹ BNAME= $bname_data[$count] ޤƻΥ饤Ȥ $CNAME ѹޤ$count $qudata");
      print("\n");

      $result = pg_query($conn, $qudata);
      if(!$result){
         print("NG bud query $select_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num < 0){
         print("NG monitor DB ƻ꤬ѹƤޤ\n");
         exit;
         }
      pg_free_result($result);
      }
   }



print("OK DBѹϴλޤ\n");



//------ եȿǡCNAMEΥꥹȤ -----//

printf("------- եȿǤƤޤ --------\n");
if($cname_count < 0){
   exit;
   }
else{
   for($count = 0; $count < $cname_count; $count++){
      print("ѹΥ饤(1)  $cname_data[$count]  ֹ桡 $count");
      print("\n");

      if($new_cname_ok == 1){
         print("ѹ奯饤(2) $CNAME");
         print("\n");
         list_file_upload($CNAME, $GEN);
         }

      list_file_upload($cname_data[$count], $GEN);
      }
   }



pg_free_result($result);
pg_Close($conn);

?>

</pre>
</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/userblock_cut_edit.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(3)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

// function WinCls(){
//        window.close()
//                       }
//  window.onload=WinCls();
//-->";
echo "</SCRIPT>";

echo "</head>";
echo "<body alink='#ff0000' bgcolor='#ffffff' link='#0000ff' text='#000000' vlink='#000080'>";

echo "<pre>";

$GEN = enco($_GET["GEN"]);

// $BNAME = enco($_GET["BNAME"]);
$CNAME = enco($_GET["CNAME"]);
$MAILTO = enco($_GET["MAILTO"]);
$MAILCC = enco($_GET["MAILCC"]);
$MAILSEND = enco($_GET["MAILSEND"]);
$PLUSTIME = enco($_GET["PLUSTIME"]);
$STAT = enco($_GET["STAT"]);
$STARTTIME = enco($_GET["STARTTIME"]);
$STOPSETTIME = enco($_GET["STOPSETTIME"]);
$FREE1 = enco($_GET["FREE1"]);
$select = enco($_GET["SELECT"]);



// ֤˴֤륨顼å
if(0 != strcmp("ASCII", mb_detect_encoding($STARTTIME))){
   print("NG NOT ASCII enc \n");
   $STARTTIME = "";
   }
if(0 != strcmp("ASCII", mb_detect_encoding($STOPSETTIME))){
   print("NG NOT ASCII enc \n");
   $STOPSETTIME = "";
   }
if(5 != strlen($STARTTIME)){
   print("NG NOT time format 00:00 \n");
   $STARTTIME = "";
   }
if( 5 != strlen($STOPSETTIME)){
   print("NG NOT time format 00:00 \n");
   $STOPSETTIME = "";
   }
if(!preg_match("/^[0-9]+$/", substr($STARTTIME, 0, 2))){
   print("NG NOT a int\n");
   $STARTTIME = "";
   }
if(!preg_match("/^[0-9]+$/", substr($STOPSETTIME, 3, 4))){
   print("NG NOT a int\n");
   $STOPSETTIME = "";
   }





$new_cname_ok = 0;
$count = 0;
$SE="LIKE";
$EE="=";

// ----- DB ³ ----//

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }


// ------ ƤΤǤ -----//
if(0 != strlen($select)){
   $select_get = urldecode($select);
   print("ƤΤǤ $select_get \n");
   $select_data = "update userblock set ";
   }
else{
   echo "NG NOT WHER DATA! \n";
   exit;
   }





// ------ ѹƤκ -----//
print("------ Ƥޤ -----\n");
if(0 != strlen($MAILTO)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " mailto='$MAILTO'";
   }

if(0 != strlen($MAILCC)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " MAILCC='$MAILCC'";
   }

if(0 != strlen($MAILSEND)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " MAILSEND='$MAILSEND'";
   }

if(0 != strlen($PLUSTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " plustime='$PLUSTIME'";
   }

if(0 != strlen($STAT)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " stat='$STAT'";
   }

if(0 != strlen($STARTTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " starttime='$STARTTIME'";
   }

if(0 != strlen($STOPSETTIME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " stopsettime='$STOPSETTIME'";
   }

if(0 != strlen($FREE1)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " free1='$FREE1'";
   }
print("ؤ󤳤Ƥκ: $select_data ");





// CNAME ѹϥå
if(0 != strlen($CNAME)){
   if($count > 0){
      $select_data = $select_data . ", ";
      }
   $count++; 
   $select_data = $select_data . " cname='$CNAME'";
   $new_cname_ok = 1;

   print("CNAME ѹޤ new_cname_ok = $new_cname_ok\n");
   print("狼 ƻ֥å̾ꥹȺ \n");

   $bname_count = 0;
   $result = pg_query($conn, "select distinct(bname) from userblock $select_get;");
   if(!$result){
      print("banem select , bud query\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num > 0){
      while($bname_count < $num){
         $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
         print("ֹ ($bname_count) 狼鸡BNAME= $bname_data[$bname_count] ꥹȤɲ\n");
         $bname_count++;
         }
      }
   else{
      print("NG ƻ֥å̵Ǥ \n");
      }
   pg_free_result($result);

   }



print("COUNT = $count DATA $select_data\n");
if(0 == $count){
   print("NG SELECT DATA ERR ѹ̵Τǽλޤ\n");
   exit;
   }



$select_data = $select_data . " $select_get";

print("UPDATE COMMAND = $select_data\n");






print("ѹCNAMEꥹ \n");

$result = pg_query($conn, "select distinct(cname) from userblock $select_get");
if(!$result){
   print("NG bud query\n");
   exit;
   }
$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   exit;
   }
else{
   $cname_count =0;
   while($cname_count < $num){
      $cname_data[$cname_count]  = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
      print("ֹ ($cname_count) 狼ѹ饤Ȥꥹ CNAME= $cname_data[$cname_count]");
      print("\n");
      $cname_count++;
      }
   }
if($cname_count < 0){
   print("NG:  ѹ饤ȤΥꥹȤޤǤ \n");
   exit;
   }



print("------ userblock DBѹޤ------- \n");


if(0 == strlen($select_data)){
   print("NG NOT select_data");
   exit;
   }
else{
   $result = pg_query($conn, "$select_data");
   print("ƻѹ夦Ǥ select_data = $select_data\n");
   if(!$result){
      print("NG bud query $select_data\n");
      exit;
      }
   $num = pg_num_rows($result);
   if($num < 0){
      print("NG ƻ֥å꤬ѹƤޤ\n");
      exit;
      }
   }
if($new_cname_ok == 1){

   print("------ monitor DBѹޤ------- \n");

   for($count = 0; $count < $bname_count; $count++){

      $qudata =  "update monitor set cname = " . "'" . $CNAME . "'" . " where free4 = " . "'" . $bname_data[$count] . "'";

      print("CNAMEѹ BNAME= $bname_data[$count] ޤƻΥ饤Ȥ $CNAME ѹޤ$count $qudata");
      print("\n");

      $result = pg_query($conn, $qudata);
      if(!$result){
         print("NG bud query $select_data\n");
         exit;
         }
      $num = pg_num_rows($result);
      if($num < 0){
         print("NG monitor DB ƻ꤬ѹƤޤ\n");
         exit;
         }
      pg_free_result($result);
      }
   }



print("OK DBѹϴλޤ\n");



//------ եȿǡCNAMEΥꥹȤ -----//

printf("------- եȿǤƤޤ --------\n");
if($cname_count < 0){
   exit;
   }
else{
   for($count = 0; $count < $cname_count; $count++){
      print("ѹΥ饤(1)  $cname_data[$count]  ֹ桡 $count");
      print("\n");

      if($new_cname_ok == 1){
         print("ѹ奯饤(2) $CNAME");
         print("\n");
         list_file_upload($CNAME, $GEN);
         }

      list_file_upload($cname_data[$count], $GEN);
      }
   }



pg_free_result($result);
pg_Close($conn);

?>

</pre>
</body>
</html>
